@@ -21,44 +21,6 @@ class Worker(object):
     _started_timestamp = None
     _life_timeout_sec = None
 
-    def init(self, config_dict=None, connection=None, schema=None, keep_connection=False):
-        func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
-        try:
-            if config_dict is None and connection is None:
-                print(f'Error in {func_name}: config_dict is None and connection is None; return...')
-                return False
-            auto_disconnect = not keep_connection
-            if connection is not None:
-                if schema is None:
-                    print(f'Error in {func_name}: connection is not None and schema is None; return...')
-                    return False
-                auto_disconnect = False
-            database_dict = None
-            if isinstance(config_dict, dict):
-                database_dict = config_dict.get('database')
-                if not isinstance(database_dict, dict):
-                    print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
-                    return False
-                worker_cfg = config_dict.get('worker')
-                if isinstance(worker_cfg, dict):
-                    self._timeout_sec = float(worker_cfg.get('timeout_sec', self._timeout_sec))
-                    self._sleep_sec = float(worker_cfg.get('sleep_sec', self._sleep_sec))
-                    self._life_timeout_sec = float(worker_cfg.get('life_timeout_sec', self._life_timeout_sec))
-            kwargs = {'settings': database_dict,
-                      'connection': connection,
-                      'schema': schema,
-                      'auto_disconnect': auto_disconnect}
-            if not database.init(**kwargs):
-                print(f'Error in {func_name}: not database.init(); return...')
-                return False
-            if not database.test_tables(create=False):
-                print(f'Error in {func_name}: not database.test_tables(); return...')
-                return False
-            return True
-        except Exception as e:
-            print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
-            return False
-
     def check_module(self, module_name):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         module_spec = importlib.util.find_spec(module_name)
@@ -215,31 +177,58 @@ class Worker(object):
         except Exception as e:
             print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
 
-    def start(self, blocking=True, sleep_sec=None, process_type=None, timeout_sec=None, life_timeout_sec=None):
+    def start(self, config_dict):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
-        if process_type is not None:
+        try:
+            if not isinstance(config_dict, dict):
+                print(f'Error in {func_name}: not isinstance(config_dict, dict); return...')
+                return
+
+            database_dict = config_dict.get('database')
+            if not isinstance(database_dict, dict):
+                print(f'Error in {func_name}: not isinstance(database_dict, dict)...')
+                return
+
+            kwargs = {'settings': database_dict}
+            if not database.init(**kwargs):
+                print(f'Error in {func_name}: not database.init(); return...')
+                return False
+            if not database.test_tables(create=False):
+                print(f'Error in {func_name}: not database.test_tables(); return...')
+                return False
+
+            process_type = 'none'
+            worker_cfg = config_dict.get('worker')
+            if isinstance(worker_cfg, dict):
+                self._timeout_sec = float(worker_cfg.get('timeout_sec', self._timeout_sec))
+                self._sleep_sec = float(worker_cfg.get('sleep_sec', self._sleep_sec))
+                self._life_timeout_sec = float(worker_cfg.get('life_timeout_sec', self._life_timeout_sec))
+                blocking = worker_cfg.get('blocking')
+                if isinstance(blocking, str):
+                    self._blocking = False if worker_cfg.get('blocking', 'true').lower() == 'false' else True
+                elif isinstance(blocking, bool):
+                    self._blocking = blocking
+                process_type = worker_cfg.get('process_type', process_type)
+
             if process_type.lower() not in ['fork', 'thread', 'kthread', 'none', '<none>']:
                 print(f'Error in {func_name}: unknown process_type "{process_type}"...')
                 return
-        self._blocking = blocking
-        if isinstance(sleep_sec, float):
-            self._sleep_sec = sleep_sec
-        if isinstance(timeout_sec, float):
-            self._timeout_sec = timeout_sec
-        # if isinstance(life_timeout_sec, float):
-        self._life_timeout_sec = life_timeout_sec
-        self._started = True
-        self._started_timestamp = datetime.datetime.now()
-        if self._blocking:
-            while self._started:
+
+            self._started = True
+            self._started_timestamp = datetime.datetime.now()
+            if self._blocking:
+                while self._started:
+                    self._do_task(process_type)
+                    time.sleep(self._sleep_sec)
+                    if self._life_timeout_sec is not None:
+                        time_delta = datetime.datetime.now() - self._started_timestamp
+                        if time_delta.total_seconds() > self._life_timeout_sec:
+                            break
+            else:
                 self._do_task(process_type)
-                time.sleep(self._sleep_sec)
-                if self._life_timeout_sec is not None:
-                    time_delta = datetime.datetime.now() - self._started_timestamp
-                    if time_delta.total_seconds() > self._life_timeout_sec:
-                        break
-        else:
-            self._do_task(process_type)
+        except Exception as e:
+            print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
+            raise e
 
     def stop(self):
         self._started = False
